@@ -53,7 +53,7 @@
 extern int main_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 25 "lib/cfg-grammar.y"
+#line 25 "/source/lib/cfg-grammar.y"
 
 
 /* this block is inserted into cfg-grammar.h, so it is included
@@ -201,8 +201,10 @@ extern int main_debug;
     KW_THREADED = 10171,           /* KW_THREADED  */
     KW_PASS_UNIX_CREDENTIALS = 10180, /* KW_PASS_UNIX_CREDENTIALS  */
     KW_PERSIST_NAME = 10181,       /* KW_PERSIST_NAME  */
-    KW_READ_OLD_RECORDS = 10182,   /* KW_READ_OLD_RECORDS  */
-    KW_USE_SYSLOGNG_PID = 10183,   /* KW_USE_SYSLOGNG_PID  */
+    KW_USE_SYSLOGNG_PID = 10182,   /* KW_USE_SYSLOGNG_PID  */
+    KW_READ_OLD_RECORDS = 10185,   /* KW_READ_OLD_RECORDS  */
+    KW_IGNORE_SAVED_BOOKMARKS = 10186, /* KW_IGNORE_SAVED_BOOKMARKS  */
+    KW_DISABLE_BOOKMARKS = 10187,  /* KW_DISABLE_BOOKMARKS  */
     KW_FLAGS = 10190,              /* KW_FLAGS  */
     KW_PAD_SIZE = 10200,           /* KW_PAD_SIZE  */
     KW_TIME_ZONE = 10201,          /* KW_TIME_ZONE  */
@@ -217,11 +219,13 @@ extern int main_debug;
     KW_TIME_REOPEN = 10210,        /* KW_TIME_REOPEN  */
     KW_TIME_REAP = 10211,          /* KW_TIME_REAP  */
     KW_TIME_SLEEP = 10212,         /* KW_TIME_SLEEP  */
-    KW_PARTITIONS = 10213,         /* KW_PARTITIONS  */
-    KW_PARTITION_KEY = 10214,      /* KW_PARTITION_KEY  */
     KW_PARALLELIZE = 10215,        /* KW_PARALLELIZE  */
+    KW_PARTITIONS = 10216,         /* KW_PARTITIONS  */
+    KW_PARTITION_KEY = 10217,      /* KW_PARTITION_KEY  */
     KW_TMPL_ESCAPE = 10220,        /* KW_TMPL_ESCAPE  */
-    KW_OPTIONAL = 10230,           /* KW_OPTIONAL  */
+    KW_LOG_FETCH_DELAY = 10230,    /* KW_LOG_FETCH_DELAY  */
+    KW_LOG_FETCH_RETRY_DELAY = 10231, /* KW_LOG_FETCH_RETRY_DELAY  */
+    KW_OPTIONAL = 10235,           /* KW_OPTIONAL  */
     KW_CREATE_DIRS = 10240,        /* KW_CREATE_DIRS  */
     KW_OWNER = 10250,              /* KW_OWNER  */
     KW_GROUP = 10251,              /* KW_GROUP  */
@@ -413,8 +417,10 @@ extern int main_debug;
 #define KW_THREADED 10171
 #define KW_PASS_UNIX_CREDENTIALS 10180
 #define KW_PERSIST_NAME 10181
-#define KW_READ_OLD_RECORDS 10182
-#define KW_USE_SYSLOGNG_PID 10183
+#define KW_USE_SYSLOGNG_PID 10182
+#define KW_READ_OLD_RECORDS 10185
+#define KW_IGNORE_SAVED_BOOKMARKS 10186
+#define KW_DISABLE_BOOKMARKS 10187
 #define KW_FLAGS 10190
 #define KW_PAD_SIZE 10200
 #define KW_TIME_ZONE 10201
@@ -429,11 +435,13 @@ extern int main_debug;
 #define KW_TIME_REOPEN 10210
 #define KW_TIME_REAP 10211
 #define KW_TIME_SLEEP 10212
-#define KW_PARTITIONS 10213
-#define KW_PARTITION_KEY 10214
 #define KW_PARALLELIZE 10215
+#define KW_PARTITIONS 10216
+#define KW_PARTITION_KEY 10217
 #define KW_TMPL_ESCAPE 10220
-#define KW_OPTIONAL 10230
+#define KW_LOG_FETCH_DELAY 10230
+#define KW_LOG_FETCH_RETRY_DELAY 10231
+#define KW_OPTIONAL 10235
 #define KW_CREATE_DIRS 10240
 #define KW_OWNER 10250
 #define KW_GROUP 10251
